@@ -211,7 +211,9 @@ class BmaClient(AbstractClient):
 
 
     def CreateCRObtain(self, request):
-        """版权保护-新建取证接口
+        """不对外提供接口能力了
+
+        版权保护-新建取证接口
 
         :param request: Request instance for CreateCRObtain.
         :type request: :class:`tencentcloud.bma.v20210624.models.CreateCRObtainRequest`
