@@ -143,6 +143,9 @@ INVALIDPARAMETERVALUE_INVALIDTEMPLATEDATA = 'InvalidParameterValue.InValidTempla
 # 域名取值错误。
 INVALIDPARAMETERVALUE_INVALIDEMAILIDENTITY = 'InvalidParameterValue.InvalidEmailIdentity'
 
+# 密码长度为10~20位，且必须至少包含2位不重复的数字、小写字母、大写字母。
+INVALIDPARAMETERVALUE_INVALIDSMTPPASSWORD = 'InvalidParameterValue.InvalidSmtpPassWord'
+
 # 您没有这个发件地址，请检查是否存在。
 INVALIDPARAMETERVALUE_NOSUCHSENDER = 'InvalidParameterValue.NoSuchSender'
 
@@ -179,6 +182,9 @@ INVALIDPARAMETERVALUE_TEMPLATECONTENTISWRONG = 'InvalidParameterValue.TemplateCo
 # 模板参数必须为json格式。
 INVALIDPARAMETERVALUE_TEMPLATEDATAERROR = 'InvalidParameterValue.TemplateDataError'
 
+# 模板参数变量名与之前不一致。
+INVALIDPARAMETERVALUE_TEMPLATEDATAINCONSISTENT = 'InvalidParameterValue.TemplateDataInconsistent'
+
 # 单条收件人地址附带的模板参数(整个 JSON 结构)， 长度超过限制 800 bytes
 INVALIDPARAMETERVALUE_TEMPLATEDATALENLIMIT = 'InvalidParameterValue.TemplateDataLenLimit'
 
@@ -200,12 +206,15 @@ INVALIDPARAMETERVALUE_WRONGDATE = 'InvalidParameterValue.WrongDate'
 # 超过配额限制。
 LIMITEXCEEDED = 'LimitExceeded'
 
-# 收件人个数限制20000个以内。
-LIMITEXCEEDED_EXCEEDRECEIVERDETAILLIMIT = 'LimitExceeded.ExceedReceiverDetailLimit'
-
 # 收件人列表数量超过限制。
 LIMITEXCEEDED_EXCEEDRECEIVERLIMIT = 'LimitExceeded.ExceedReceiverLimit'
 
+# 该收件人列表包含的收件人地址总量超过限制。
+LIMITEXCEEDED_RECEIVERDETAILCOUNTLIMIT = 'LimitExceeded.ReceiverDetailCountLimit'
+
+# 请求的收件人地址数量超过限制。
+LIMITEXCEEDED_RECEIVERDETAILREQUESTLIMIT = 'LimitExceeded.ReceiverDetailRequestLimit'
+
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
@@ -245,6 +254,9 @@ OPERATIONDENIED_RECEIVERNOTEXIST = 'OperationDenied.ReceiverNotExist'
 # 收件人列表空或状态不是上传完成。
 OPERATIONDENIED_RECEIVERSTATUSERROR = 'OperationDenied.ReceiverStatusError'
 
+# 不能与上一次设置密码相同。
+OPERATIONDENIED_REPEATPASSWORD = 'OperationDenied.RepeatPassWord'
+
 # 发信地址不存在或者状态不是通过状态。
 OPERATIONDENIED_SENDADDRESSSTATUSERROR = 'OperationDenied.SendAddressStatusError'
 
